import { createLocalVue, shallowMount } from "@vue/test-utils";
import Vuex from "vuex";
import LayoutBuilder from "../../src/LayoutBuilder.vue";
import state from "../mocks/state";
import Store from "../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);
const currentState = { foo: "bar" };

localVue.use(Vuex);

window.fetch = jest.fn(
  () =>
    new Promise(resolve =>
      resolve({
        ok: true,
        json: () => new Promise(res => res(currentState))
      })
    )
);

describe("LayoutBuilder.vue", () => {
  const stateUrl = "http://example.com";

  it("renders the PageLayout component", () => {
    const wrapper = shallowMount(LayoutBuilder, {
      mocks: {
        stateUrl,
        $store: store
      }
    });
    expect(wrapper.findAll("layoutbuilderpagelayout-stub").length).toBe(1);
  });

  it("renders the PageLayoutForm component", () => {
    const wrapper = shallowMount(LayoutBuilder, {
      mocks: {
        stateUrl,
        $store: store
      }
    });
    expect(wrapper.findAll("layoutbuilderpagelayoutform-stub").length).toBe(1);
  });
});
